@@ -16,14 +16,15 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, 
+ * Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
 
 #include <math.h>
+#include <libgitg/gitg-lane.h>
+#include <libgitg/gitg-revision.h>
+
 #include "gitg-cell-renderer-path.h"
-#include "gitg-lane.h"
-#include "gitg-utils.h"
 #include "gitg-label-renderer.h"
 
 #define GITG_CELL_RENDERER_PATH_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GITG_TYPE_CELL_RENDERER_PATH, GitgCellRendererPathPrivate))
@@ -325,7 +326,7 @@ renderer_render(GtkCellRenderer *renderer, GdkDrawable *window, GtkWidget *widge
 
 	cairo_t *cr = gdk_cairo_create(window);
 
-	cairo_rectangle(cr, area->x, area->y, area->width, area->height);
+	gdk_cairo_rectangle (cr, area);
 	cairo_clip(cr);
 
 	draw_paths(self, cr, area);
